@@ -112,7 +112,7 @@ print.bridgesde1d <- function(x, digits=NULL, ...)
         "Method:","\n",
         "\t| ",sch,"\n",
         "Summary:","\n",
-        "\t| Size of process","\t| N  = ",format(x$N,digits=digits),".","\n",
+        "\t| Size of process","\t| N  = ",format(x$N+1,digits=digits),".","\n",
         "\t| Crossing realized","\t| C  = ",format(length(which(!is.na(x$C))),digits=digits),".","\n",
         "\t| Initial value","\t\t| x0 = ",format(x$x0,digits=digits),".","\n",
         "\t| Ending value","\t\t| y = ",format(x$y,digits=digits),".","\n",
@@ -124,7 +124,7 @@ print.bridgesde1d <- function(x, digits=NULL, ...)
         "Method:","\n",
         "\t| ",sch,"\n",
         "Summary:","\n",
-        "\t| Size of process","\t| N  = ",format(x$N,digits=digits),".","\n",
+        "\t| Size of process","\t| N  = ",format(x$N+1,digits=digits),".","\n",
         "\t| Crossing realized","\t| C  = ",format(length(which(!is.na(x$C))),digits=digits),".","\n",
         "\t| Initial value","\t\t| x0 = ",format(x$x0,digits=digits),".","\n",
         "\t| Ending value","\t\t| y = ",format(x$y,digits=digits),".","\n",
@@ -392,7 +392,7 @@ print.bridgesde2d <- function(x, digits=NULL, ...)
         "Method:","\n",
         "\t| ",sch,"\n",
         "Summary:","\n",
-        "\t| Size of process","\t| N  = ",format(x$N,digits=digits),".","\n",
+        "\t| Size of process","\t| N  = ",format(x$N+1,digits=digits),".","\n",
         "\t| Crossing realized","\t| (Cx,Cy) = c","(",format(length(which(!is.na(x$Cx))),digits=digits),",",format(length(which(!is.na(x$Cy))),digits=digits),")",".","\n",
         "\t| Initial values","\t| x0 = c","(",format(x$x0[1],digits=digits),",",format(x$x0[2],digits=digits),")",".","\n",
         "\t| Ending values","\t\t| y  = c","(",format(x$y[1],digits=digits),",",format(x$y[2],digits=digits),")",".","\n",
@@ -405,7 +405,7 @@ print.bridgesde2d <- function(x, digits=NULL, ...)
         "Method:","\n",
         "\t| ",sch,"\n",
         "Summary:","\n",
-        "\t| Size of process","\t| N  = ",format(x$N,digits=digits),".","\n",
+        "\t| Size of process","\t| N  = ",format(x$N+1,digits=digits),".","\n",
         "\t| Crossing realized","\t| (Cx,Cy) = c","(",format(length(which(!is.na(x$Cx))),digits=digits),",",format(length(which(!is.na(x$Cy))),digits=digits),")",".","\n",
         "\t| Initial values","\t| x0 = c","(",format(x$x0[1],digits=digits),",",format(x$x0[2],digits=digits),")",".","\n",
         "\t| Ending values","\t\t| y  = c","(",format(x$y[1],digits=digits),",",format(x$y[2],digits=digits),")",".","\n",
@@ -737,7 +737,7 @@ print.bridgesde3d <- function(x, digits=NULL, ...)
         "Method:","\n",
         "\t| ",sch,"\n",
         "Summary:","\n",
-        "\t| Size of process","\t| N  = ",format(x$N,digits=digits),".","\n",
+        "\t| Size of process","\t| N  = ",format(x$N+1,digits=digits),".","\n",
         "\t| Crossing realized","\t| (Cx,Cy,Cz) = c","(",format(length(which(!is.na(x$Cx))),digits=digits),",",format(length(which(!is.na(x$Cy))),digits=digits),",",format(length(which(!is.na(x$Cz))),digits=digits),")",".","\n",
         "\t| Initial values","\t| x0 = c","(",format(x$x0[1],digits=digits),",",format(x$x0[2],digits=digits),",",format(x$x0[3],digits=digits),")",".","\n",
         "\t| Ending values","\t\t| y  = c","(",format(x$y[1],digits=digits),",",format(x$y[2],digits=digits),",",format(x$y[3],digits=digits),")",".","\n",
@@ -751,7 +751,7 @@ print.bridgesde3d <- function(x, digits=NULL, ...)
         "Method:","\n",
         "\t| ",sch,"\n",
         "Summary:","\n",
-        "\t| Size of process","\t| N  = ",format(x$N,digits=digits),".","\n",
+        "\t| Size of process","\t| N  = ",format(x$N+1,digits=digits),".","\n",
         "\t| Crossing realized","\t| (Cx,Cy,Cz) = c","(",format(length(which(!is.na(x$Cx))),digits=digits),",",format(length(which(!is.na(x$Cy))),digits=digits),",",format(length(which(!is.na(x$Cz))),digits=digits),")",".","\n",
         "\t| Initial values","\t| x0 = c","(",format(x$x0[1],digits=digits),",",format(x$x0[2],digits=digits),",",format(x$x0[3],digits=digits),")",".","\n",
         "\t| Ending values","\t\t| y  = c","(",format(x$y[1],digits=digits),",",format(x$y[2],digits=digits),",",format(x$y[3],digits=digits),")",".","\n",
