@@ -1,5 +1,5 @@
-## Tue Oct 04 00:34:00 2016
-## Original file Copyright © 2016 A.C. Guidoum, K. Boukhetala
+## Fri Mar 24 23:26:35 2017
+## Original file Copyright © 2017 A.C. Guidoum, K. Boukhetala
 ## This file is part of the R package Sim.DiffProc
 ## Department of Probabilities & Statistics
 ## Faculty of Mathematics
@@ -49,12 +49,14 @@ add.bconfint.default <- function(x,level = 0.95,...)
 
 moment <- function(x, ...)  UseMethod("moment")
 
-moment.default <- function(x, order = 2,...)
+moment.default <- function(x, order = 1,center = TRUE,...)
             {
     if (any(!is.numeric(order)  || (order - floor(order) > 0) || order < 1)) stop(" 'order' must be a positive integer ")
-    ifelse(order == 1,return(0),return(mean((x - mean(x,na.rm = TRUE))^order,na.rm = TRUE)))
+    if (center) x <- x - mean(x)
+    return(sum(x^order)/length(x))
          }
 
+
 ###
 ### Computes the sample skewness
 
@@ -120,9 +122,9 @@ plot3DD <- function(X,Y,Z,display = c("persp","rgl"),col=NULL,lwd=NULL,pch=NULL,
     if (is.null(type)) {type = "l"}
     if (is.null(main)) {main = ""}
     if (is.null(sub))  {sub = ""}
-    if (is.null(xlab)) {xlab = expression(X[t])}
-    if (is.null(ylab)) {ylab = expression(Y[t])}
-    if (is.null(zlab)) {zlab = expression(Z[t])} 
+    if (is.null(xlab)) {xlab = expression(x)}
+    if (is.null(ylab)) {ylab = expression(y)}
+    if (is.null(zlab)) {zlab = expression(z)} 
     if (is.null(grid)) {grid = TRUE}   
     if (is.null(angle)){angle = 140} 
     if (display=="persp"){
@@ -183,8 +185,8 @@ plot3D.default <- function(x,display = c("persp", "rgl"),...) plot3DD(x,display,
                  {
     class(x) <- "snssde2d"
     if (is.null(type)){type="l"}
-    if (is.null(ylab)){ylab=expression(Y[t])}
-    if (is.null(xlab)){xlab=expression(X[t])}
+    if (is.null(ylab)){ylab=expression(y)}
+    if (is.null(xlab)){xlab=expression(x)}
     if (x$M == 1){X = matrix(x$X,nrow=length(x$X),ncol=1)
                   Y = matrix(x$Y,nrow=length(x$Y),ncol=1)}else{
                   X = x$X
@@ -886,13 +888,75 @@ plot3D.default <- function(x,display = c("persp", "rgl"),...) plot3DD(x,display,
 
 ####
 #### plot for calss dsde3d
+.plotks.3d <- function(fhat,display=c("rgl","persp"), cont=c(25,50,75), abs.cont, approx.cont=TRUE, colors, col.fun, alphavec, size=3, col.pt="blue", add=FALSE, xlab, ylab, zlab, drawpoints=FALSE, alpha=1, box=TRUE, axes=TRUE, ...)
 
-.plot.dsde3d <- function(x,hist=FALSE,legend=TRUE,pos=2,main=NULL,xlab=NULL,ylab=NULL,zlab=NULL,col=NULL,border=NULL,
-                          lwd=NULL,cex=NULL,las=NULL,lty=NULL,xlim=NULL,ylim=NULL,...) 
+{
+  ## compute contours
+  if (missing(abs.cont))
+  {
+    if (!is.null(fhat$cont))
+      {
+        cont.ind <- rep(FALSE, length(fhat$cont))
+          for (j in 1:length(cont))
+            cont.ind[which(cont[j] == 100-as.numeric(unlist(strsplit(names(fhat$cont),"%"))))] <- TRUE
+          
+        if (all(!cont.ind))
+          hts <- contourLevels(fhat, prob=(100-cont)/100, approx=approx.cont)
+        else
+          hts <- fhat$cont[cont.ind]
+      }
+    else
+      hts <- contourLevels(fhat, prob=(100-cont)/100, approx=approx.cont)
+  }  
+  else
+    hts <- abs.cont
+  
+  nc <- length(hts)
+  
+  if (missing(colors)) colors <- rev(heat.colors(nc))
+  if (!missing(col.fun)) colors <- col.fun(nc)
+  if (missing(xlab)) xlab <- fhat$names[1]
+  if (missing(ylab)) ylab <- fhat$names[2]
+  if (missing(zlab)) zlab <- fhat$names[3]
+  if (missing(alphavec))
+  {
+    if (is.null(fhat$deriv.order)) alphavec <- seq(0.1,0.5,length=nc)
+    else alphavec <- c(rev(seq(0.1,0.4,length=round(nc/2))), seq(0.1,0.4,length=round(nc/2)))
+  }
+ 
+  fhat.eval.mean <- sapply(fhat$eval.points, mean)
+  display <- match.arg(display)
+  if (display=="rgl"){
+  if (drawpoints)
+    rgl::plot3d(fhat$x[,1],fhat$x[,2],fhat$x[,3], size=size, col=col.pt, alpha=alpha, xlab=xlab, ylab=ylab, zlab=zlab, add=add, box=FALSE, axes=FALSE, ...)
+  else
+    rgl::plot3d(fhat$x[,1],fhat$x[,2],fhat$x[,3], size=0, col="transparent", alpha=0, xlab=xlab, ylab=ylab, zlab=zlab, add=add, box=FALSE, axes=FALSE, ...)  
+  
+  for (i in 1:nc)
+    if (hts[nc-i+1] < max(fhat$estimate))
+      misc3d::contour3d(fhat$estimate, level=hts[nc-i+1], x=fhat$eval.points[[1]], y=fhat$eval.points[[2]], z=fhat$eval.points[[3]], add=TRUE, color=colors[i], alpha=alphavec[i], box=FALSE, axes=FALSE, ...)
+
+  if (axes) axes3d()
+  if (box) box3d()}else{
+  #if (drawpoints)
+  #scatterplot3d::scatterplot3d(fhat$x[,1],fhat$x[,2],fhat$x[,3], type="p",xlab="x",ylab="y",zlab="z",color=col.pt,axis=axes,box=box,xlim=c(min(fhat$eval.points[[1]],na.rm =TRUE),max(fhat$eval.points[[1]]),na.rm =TRUE),ylim=c(min(fhat$eval.points[[2]],na.rm =TRUE),max(fhat$eval.points[[2]]),na.rm =TRUE),zlim=c(min(fhat$eval.points[[3]],na.rm =TRUE),max(fhat$eval.points[[3]]),na.rm =TRUE),...)
+  #else
+  #scatterplot3d::scatterplot3d(fhat$x[,1],fhat$x[,2],fhat$x[,3], type="n",xlab="x",ylab="y",zlab="z",axis=axes,box=box,xlim=c(min(fhat$eval.points[[1]],na.rm =TRUE),max(fhat$eval.points[[1]],na.rm =TRUE)),ylim=c(min(fhat$eval.points[[2]],na.rm =TRUE),max(fhat$eval.points[[2]],na.rm =TRUE)),zlim=c(min(fhat$eval.points[[3]],na.rm =TRUE),max(fhat$eval.points[[3]],na.rm =TRUE)),...)
+  plot(0,type="n",axes=FALSE,xlab="",ylab="",xlim=c(min(fhat$eval.points[[1]],na.rm =TRUE),max(fhat$eval.points[[1]],na.rm =TRUE)),ylim=c(min(fhat$eval.points[[2]],na.rm =TRUE),max(fhat$eval.points[[2]],na.rm =TRUE)))
+  misc3d::contour3d(fhat$estimate, level=hts[nc-nc+1], x=fhat$eval.points[[1]], y=fhat$eval.points[[2]], z=fhat$eval.points[[3]], add=TRUE, color=colors[1], alpha=alphavec[nc], engine = "standard",perspective=0,...)
+  for (i in 1:(nc-1))
+    if (hts[nc-i+1] < max(fhat$estimate))
+      misc3d::contour3d(fhat$estimate, level=hts[nc-i+1], x=fhat$eval.points[[1]], y=fhat$eval.points[[2]], z=fhat$eval.points[[3]], add=TRUE, color=colors[i], alpha=alphavec[i], engine = "standard",perspective=0, ...)
+}
+}
+
+.plot.dsde3d <- function(x,display=c("rgl","persp"),hist=FALSE,legend=TRUE,pos=2,main=NULL,xlab=NULL,ylab=NULL,zlab=NULL,col=NULL,border=NULL,
+                          lwd=NULL,cex=NULL,las=NULL,lty=NULL,xlim=NULL,ylim=NULL,color.palette=NULL,...) 
 {
     class(x) <- "dsde3d"
     if (is.null(col)){col= c(rgb(255,0,0,75,maxColorValue=255),rgb(0,0,255,75,maxColorValue=255),rgb(0,255,0,75,maxColorValue=255))}
     if (is.null(border)){border = c(rgb(255,0,0,130,maxColorValue=255),rgb(0,0,255,130,maxColorValue=255),rgb(0,255,0,130,maxColorValue=255))}
+	if (is.null(color.palette)){color.palette=colorRampPalette(c('white','green','blue','orange','red'))}
     if (is.null(lty)){lty=1}
     if (is.null(lwd)){lwd=1}
     if (is.null(cex)){cex=1}
@@ -910,7 +974,8 @@ plot3D.default <- function(x,display = c("persp", "rgl"),...) plot3DD(x,display,
     else if (pos==7){pos = "bottom"}
     else if (pos==8){pos = "bottomright"}
     else if (pos==9){pos = "bottomleft"}
-
+    display <- match.arg(display)
+    if (x$pdf =='Marginal'){
         if (hist==FALSE){ 
 		if (missing(xlim)) {xlim = c(min(c(x$resx$x, x$resy$x,x$resz$x)) , max(c(x$resx$x, x$resy$x, x$resz$x)))}
 		if (missing(ylim)) {ylim = c(min(c(x$resx$y, x$resy$y,x$resz$y)) , max(c(x$resx$y, x$resy$y, x$resz$y)))}
@@ -926,6 +991,13 @@ plot3D.default <- function(x,display = c("persp", "rgl"),...) plot3DD(x,display,
           MASS::truehist(x$ech$y,xlab = "y",main=main,las=las,col=col[2],...);box()
           dev.new()
           MASS::truehist(x$ech$z,xlab = "z",main=main,las=las,col=col[3],...);box()
+    }}else if (x$pdf =='Joint'){
+    col3 <- heat.colors(length(x$res$z))[rank(x$res$z)]
+    if (display=="persp"){
+      .plotks.3d(x$res,display="persp",...)
+    }else if (display=="rgl"){
+      .plotks.3d(x$res,display="rgl",...)
+    }
     }
 }
 
